SnapshotViewExtension extension

This extension makes getters available to convert the JSON content to dart objects on classes extending SnapshotViews.

on

Properties

snapshot → Snapshot

Available on SnapshotView, provided by the SnapshotViewExtension extension

no setter

Methods

get<T>(String path, {String? format}) → T

Available on SnapshotView, provided by the SnapshotViewExtension extension

Gets and converts the value at path to type T
getList<T>(String path, {String? format}) → List<T>?

Available on SnapshotView, provided by the SnapshotViewExtension extension

Gets and converts the value at path to type List
getMap<T>(String path, {String? format}) → Map<String, T>?

Available on SnapshotView, provided by the SnapshotViewExtension extension

Gets and converts the value at path to type Map<String,T> or null
getNonNullableList<T>(String path, {String? format}) → List<T>

Available on SnapshotView, provided by the SnapshotViewExtension extension

Gets and converts the value at path to type List
getNonNullableMap<T>(String path, {String? format}) → Map<String, T>

Available on SnapshotView, provided by the SnapshotViewExtension extension

Gets and converts the value at path to type Map<String,T>